@@ -132,7 +132,7 @@ individual_can_audio_video_call (FolksIndividual *individual,
       TpContact *tp_contact;
       EmpathyContact *contact;
 
-      if (!TPF_IS_PERSONA (l->data))
+      if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
         continue;
 
       tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
@@ -164,21 +164,21 @@ individual_get_client_types (FolksIndividual *individual)
   personas = folks_individual_get_personas (individual);
   for (l = personas; l != NULL; l = l->next)
     {
-      FolksPresenceOwner *presence;
+      FolksPresenceDetails *presence;
 
-      /* We only want personas which implement FolksPresenceOwner */
-      if (!FOLKS_IS_PRESENCE_OWNER (l->data))
+      /* We only want personas which implement FolksPresenceDetails */
+      if (!FOLKS_IS_PRESENCE_DETAILS (l->data))
         continue;
 
-      presence = FOLKS_PRESENCE_OWNER (l->data);
+      presence = FOLKS_PRESENCE_DETAILS (l->data);
 
-      if (folks_presence_owner_typecmp (
-              folks_presence_owner_get_presence_type (presence),
+      if (folks_presence_details_typecmp (
+              folks_presence_details_get_presence_type (presence),
               presence_type) > 0)
         {
           TpContact *tp_contact;
 
-          presence_type = folks_presence_owner_get_presence_type (presence);
+          presence_type = folks_presence_details_get_presence_type (presence);
 
           tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
           types = tp_contact_get_client_types (tp_contact);
@@ -204,7 +204,7 @@ add_individual_to_store (GtkTreeStore *self,
 
   gtk_tree_store_insert_with_values (self, iter, parent, 0,
       EMPATHY_INDIVIDUAL_STORE_COL_NAME,
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)),
+      folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual)),
       EMPATHY_INDIVIDUAL_STORE_COL_INDIVIDUAL, individual,
       EMPATHY_INDIVIDUAL_STORE_COL_IS_GROUP, FALSE,
       EMPATHY_INDIVIDUAL_STORE_COL_IS_SEPARATOR, FALSE,
@@ -250,14 +250,11 @@ individual_store_get_group (EmpathyIndividualStore *self,
     gboolean *created,
     gboolean is_fake_group)
 {
-  EmpathyIndividualStorePriv *priv;
   GtkTreeModel *model;
   GtkTreeIter iter_group;
   GtkTreeIter iter_separator;
   FindGroup fg;
 
-  priv = GET_PRIV (self);
-
   memset (&fg, 0, sizeof (fg));
 
   fg.name = name;
@@ -341,13 +338,10 @@ static GList *
 individual_store_find_contact (EmpathyIndividualStore *self,
     FolksIndividual *individual)
 {
-  EmpathyIndividualStorePriv *priv;
   GtkTreeModel *model;
   GList *l = NULL;
   FindContact fc;
 
-  priv = GET_PRIV (self);
-
   memset (&fc, 0, sizeof (fc));
 
   fc.individual = individual;
@@ -373,12 +367,9 @@ static void
 individual_store_remove_individual (EmpathyIndividualStore *self,
     FolksIndividual *individual)
 {
-  EmpathyIndividualStorePriv *priv;
   GtkTreeModel *model;
   GList *iters, *l;
 
-  priv = GET_PRIV (self);
-
   iters = individual_store_find_contact (self, individual);
   if (iters == NULL)
     return;
@@ -422,12 +413,14 @@ individual_store_add_individual (EmpathyIndividualStore *self,
 
   priv = GET_PRIV (self);
 
-  if (EMP_STR_EMPTY (folks_aliasable_get_alias (FOLKS_ALIASABLE (individual))))
+  if (EMP_STR_EMPTY (folks_alias_details_get_alias (
+          FOLKS_ALIAS_DETAILS (individual))))
     return;
 
   if (priv->show_groups)
     {
-      group_set = folks_groupable_get_groups (FOLKS_GROUPABLE (individual));
+      group_set = folks_group_details_get_groups (
+          FOLKS_GROUP_DETAILS (individual));
       groups = g_hash_table_get_keys (group_set);
     }
 
@@ -478,7 +471,8 @@ individual_store_add_individual (EmpathyIndividualStore *self,
   g_list_free (groups);
 
   if (priv->show_groups &&
-      folks_favouritable_get_is_favourite (FOLKS_FAVOURITABLE (individual)))
+      folks_favourite_details_get_is_favourite (
+          FOLKS_FAVOURITE_DETAILS (individual)))
     {
       /* Add contact to the fake 'Favorites' group */
       GtkTreeIter iter_group;
@@ -501,11 +495,9 @@ individual_store_contact_set_active (EmpathyIndividualStore *self,
     gboolean active,
     gboolean set_changed)
 {
-  EmpathyIndividualStorePriv *priv;
   GtkTreeModel *model;
   GList *iters, *l;
 
-  priv = GET_PRIV (self);
   model = GTK_TREE_MODEL (self);
 
   iters = individual_store_find_contact (self, individual);
@@ -558,7 +550,7 @@ individual_store_contact_active_new (EmpathyIndividualStore *self,
   ShowActiveData *data;
 
   DEBUG ("Individual'%s' now active, and %s be removed",
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)),
+      folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual)),
       remove_ ? "WILL" : "WILL NOT");
 
   data = g_slice_new0 (ShowActiveData);
@@ -603,12 +595,13 @@ individual_store_contact_active_cb (ShowActiveData *data)
   if (data->remove)
     {
       DEBUG ("Individual'%s' active timeout, removing item",
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (data->individual)));
+          folks_alias_details_get_alias (
+            FOLKS_ALIAS_DETAILS (data->individual)));
       individual_store_remove_individual (data->self, data->individual);
     }
 
   DEBUG ("Individual'%s' no longer active",
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (data->individual)));
+      folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (data->individual)));
 
   individual_store_contact_set_active (data->self,
       data->individual, FALSE, TRUE);
@@ -637,7 +630,7 @@ individual_avatar_pixbuf_received_cb (FolksIndividual *individual,
   if (error != NULL)
     {
       DEBUG ("failed to retrieve pixbuf for individual %s: %s",
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)),
+          folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual)),
           error->message);
       g_clear_error (&error);
     }
@@ -706,13 +699,13 @@ individual_store_contact_update (EmpathyIndividualStore *self,
     }
 
   /* Get online state now. */
-  now_online = folks_presence_owner_is_online (
-      FOLKS_PRESENCE_OWNER (individual));
+  now_online = folks_presence_details_is_online (
+      FOLKS_PRESENCE_DETAILS (individual));
 
   if (!in_list)
     {
       DEBUG ("Individual'%s' in list:NO, should be:YES",
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+          folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual)));
 
       individual_store_add_individual (self, individual);
 
@@ -726,7 +719,7 @@ individual_store_contact_update (EmpathyIndividualStore *self,
   else
     {
       DEBUG ("Individual'%s' in list:YES, should be:YES",
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+          folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual)));
 
       /* Get online state before. */
       if (iters && g_list_length (iters) > 0)
@@ -795,13 +788,13 @@ individual_store_contact_update (EmpathyIndividualStore *self,
           EMPATHY_INDIVIDUAL_STORE_COL_ICON_STATUS, pixbuf_status,
           EMPATHY_INDIVIDUAL_STORE_COL_PIXBUF_AVATAR_VISIBLE, show_avatar,
           EMPATHY_INDIVIDUAL_STORE_COL_NAME,
-            folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)),
+            folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual)),
           EMPATHY_INDIVIDUAL_STORE_COL_PRESENCE_TYPE,
-            folks_presence_owner_get_presence_type (
-                FOLKS_PRESENCE_OWNER (individual)),
+            folks_presence_details_get_presence_type (
+                FOLKS_PRESENCE_DETAILS (individual)),
           EMPATHY_INDIVIDUAL_STORE_COL_STATUS,
-            folks_presence_owner_get_presence_message (
-                FOLKS_PRESENCE_OWNER (individual)),
+            folks_presence_details_get_presence_message (
+                FOLKS_PRESENCE_DETAILS (individual)),
           EMPATHY_INDIVIDUAL_STORE_COL_COMPACT, priv->is_compact,
           EMPATHY_INDIVIDUAL_STORE_COL_IS_GROUP, FALSE,
           EMPATHY_INDIVIDUAL_STORE_COL_IS_ONLINE, now_online,
@@ -841,7 +834,7 @@ individual_store_individual_updated_cb (FolksIndividual *individual,
     EmpathyIndividualStore *self)
 {
   DEBUG ("Individual'%s' updated, checking roster is in sync...",
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+      folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual)));
 
   individual_store_contact_update (self, individual);
 }
@@ -991,10 +984,6 @@ individual_store_favourites_changed_cb (EmpathyIndividualManager *manager,
     gboolean is_favourite,
     EmpathyIndividualStore *self)
 {
-  EmpathyIndividualStorePriv *priv;
-
-  priv = GET_PRIV (self);
-
   DEBUG ("Individual %s is %s a favourite",
       folks_individual_get_id (individual),
       is_favourite ? "now" : "no longer");
@@ -1086,10 +1075,6 @@ individual_store_member_renamed_cb (EmpathyIndividualManager *manager,
     const gchar *message,
     EmpathyIndividualStore *self)
 {
-  EmpathyIndividualStorePriv *priv;
-
-  priv = GET_PRIV (self);
-
   DEBUG ("Individual %s renamed to %s",
       folks_individual_get_id (old_individual),
       folks_individual_get_id (new_individual));
@@ -1193,10 +1178,6 @@ individual_store_set_property (GObject *object,
     const GValue *value,
     GParamSpec *pspec)
 {
-  EmpathyIndividualStorePriv *priv;
-
-  priv = GET_PRIV (object);
-
   switch (param_id)
     {
     case PROP_INDIVIDUAL_MANAGER:
@@ -1392,8 +1373,8 @@ individual_store_contact_sort (FolksIndividual *individual_a,
 
   /* alias */
   ret_val = g_utf8_collate (
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual_a)),
-      folks_aliasable_get_alias (FOLKS_ALIASABLE (individual_b)));
+      folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual_a)),
+      folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual_b)));
 
   if (ret_val != 0)
     goto out;
@@ -1468,11 +1449,11 @@ individual_store_state_sort_func (GtkTreeModel *model,
    * the presences.
    */
   folks_presence_type_a =
-      folks_presence_owner_get_presence_type (
-          FOLKS_PRESENCE_OWNER (individual_a));
+      folks_presence_details_get_presence_type (
+          FOLKS_PRESENCE_DETAILS (individual_a));
   folks_presence_type_b =
-      folks_presence_owner_get_presence_type (
-          FOLKS_PRESENCE_OWNER (individual_b));
+      folks_presence_details_get_presence_type (
+          FOLKS_PRESENCE_DETAILS (individual_b));
   tp_presence_a = empathy_folks_presence_type_to_tp (folks_presence_type_a);
   tp_presence_b = empathy_folks_presence_type_to_tp (folks_presence_type_b);
 
@@ -1954,7 +1935,7 @@ individual_store_get_individual_status_icon_with_icon_name (
   personas = folks_individual_get_personas (individual);
   for (l = personas, contact_count = 0; l; l = l->next)
     {
-      if (TPF_IS_PERSONA (l->data))
+      if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
         contact_count++;
 
       if (contact_count > 1)
