@@ -228,20 +228,21 @@ update_weak_contact (EmpathyIndividualWidget *self)
       personas = folks_individual_get_personas (priv->individual);
       for (l = personas; l != NULL; l = l->next)
         {
-          FolksPresenceOwner *presence;
+          FolksPresenceDetails *presence;
 
           /* We only want personas which implement FolksPresence */
-          if (!FOLKS_IS_PRESENCE_OWNER (l->data))
+          if (!FOLKS_IS_PRESENCE_DETAILS (l->data))
             continue;
 
-          presence = FOLKS_PRESENCE_OWNER (l->data);
+          presence = FOLKS_PRESENCE_DETAILS (l->data);
 
-          if (folks_presence_owner_typecmp (
-                  folks_presence_owner_get_presence_type (presence),
+          if (folks_presence_details_typecmp (
+                  folks_presence_details_get_presence_type (presence),
                   presence_type) > 0 &&
               empathy_folks_persona_is_interesting (FOLKS_PERSONA (presence)))
             {
-              presence_type = folks_presence_owner_get_presence_type (presence);
+              presence_type = folks_presence_details_get_presence_type (
+                  presence);
               tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
             }
         }
@@ -468,9 +469,9 @@ groups_update (EmpathyIndividualWidget *self)
   if (priv->flags & EMPATHY_INDIVIDUAL_WIDGET_EDIT_GROUPS &&
       priv->individual != NULL)
     {
-      empathy_groups_widget_set_groupable (
+      empathy_groups_widget_set_group_details (
           EMPATHY_GROUPS_WIDGET (priv->groups_widget),
-          FOLKS_GROUPABLE (priv->individual));
+          FOLKS_GROUP_DETAILS (priv->individual));
       gtk_widget_show (priv->groups_widget);
     }
   else
@@ -791,8 +792,8 @@ location_update (EmpathyIndividualWidget *self)
 
               /* Add a marker to the map */
               marker = champlain_label_new_with_text (
-                  folks_aliasable_get_alias (FOLKS_ALIASABLE (persona)), NULL,
-                  NULL, NULL);
+                  folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (persona)),
+                  NULL, NULL, NULL);
               champlain_location_set_location (CHAMPLAIN_LOCATION (marker),
                   lat, lon);
               champlain_marker_layer_add_marker (layer,
@@ -1132,7 +1133,8 @@ entry_alias_focus_event_cb (GtkEditable *editable,
         }
       else
         {
-          folks_aliasable_set_alias (FOLKS_ALIASABLE (priv->individual), alias);
+          folks_alias_details_set_alias (FOLKS_ALIAS_DETAILS (priv->individual),
+              alias);
         }
     }
 
@@ -1144,8 +1146,8 @@ favourite_toggled_cb (GtkToggleButton *button,
     EmpathyIndividualWidget *self)
 {
   gboolean active = gtk_toggle_button_get_active (button);
-  folks_favouritable_set_is_favourite (
-      FOLKS_FAVOURITABLE (GET_PRIV (self)->individual), active);
+  folks_favourite_details_set_is_favourite (
+      FOLKS_FAVOURITE_DETAILS (GET_PRIV (self)->individual), active);
 }
 
 static void
@@ -1207,12 +1209,12 @@ notify_alias_cb (gpointer folks_object,
   if (GTK_IS_ENTRY (alias_widget))
     {
       gtk_entry_set_text (GTK_ENTRY (alias_widget),
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (folks_object)));
+          folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (folks_object)));
     }
   else
     {
       gtk_label_set_label (GTK_LABEL (alias_widget),
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (folks_object)));
+          folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (folks_object)));
     }
 }
 
@@ -1241,13 +1243,13 @@ notify_presence_cb (gpointer folks_object,
   state_image = g_object_get_data (table, "state-image");
 
   /* FIXME: Default messages should be moved into libfolks (bgo#627403) */
-  message = folks_presence_owner_get_presence_message (
-      FOLKS_PRESENCE_OWNER (folks_object));
+  message = folks_presence_details_get_presence_message (
+      FOLKS_PRESENCE_DETAILS (folks_object));
   if (EMP_STR_EMPTY (message))
     {
       message = empathy_presence_get_default_message (
-          folks_presence_owner_get_presence_type (
-              FOLKS_PRESENCE_OWNER (folks_object)));
+          folks_presence_details_get_presence_type (
+              FOLKS_PRESENCE_DETAILS (folks_object)));
     }
 
   if (message != NULL)
@@ -1257,8 +1259,8 @@ notify_presence_cb (gpointer folks_object,
 
   gtk_image_set_from_icon_name (GTK_IMAGE (state_image),
       empathy_icon_name_for_presence (
-          folks_presence_owner_get_presence_type (
-              FOLKS_PRESENCE_OWNER (folks_object))),
+          folks_presence_details_get_presence_type (
+              FOLKS_PRESENCE_DETAILS (folks_object))),
       GTK_ICON_SIZE_BUTTON);
   gtk_widget_show (state_image);
 }
@@ -1287,8 +1289,8 @@ notify_is_favourite_cb (gpointer folks_object,
   if (GTK_IS_TOGGLE_BUTTON (favourite_widget))
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (favourite_widget),
-          folks_favouritable_get_is_favourite (
-              FOLKS_FAVOURITABLE (folks_object)));
+          folks_favourite_details_get_is_favourite (
+              FOLKS_FAVOURITE_DETAILS (folks_object)));
     }
 }
 
