@@ -87,6 +87,10 @@ gboolean empathy_account_settings_has_account (
 TpConnectionManagerParam *empathy_account_settings_get_tp_params (
     EmpathyAccountSettings *settings);
 
+gboolean empathy_account_settings_have_tp_param (
+    EmpathyAccountSettings *settings,
+    const gchar *param);
+
 void empathy_account_settings_unset (EmpathyAccountSettings *settings,
     const gchar *param);
 
@@ -174,6 +178,7 @@ void empathy_account_settings_apply_async (EmpathyAccountSettings *settings,
 gboolean empathy_account_settings_apply_finish (
   EmpathyAccountSettings *settings,
   GAsyncResult *result,
+  gboolean *reconnect_required,
   GError **error);
 
 void empathy_account_settings_set_regex (EmpathyAccountSettings *settings,
