@@ -31,7 +31,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
-#include <unique/unique.h>
 
 #include <telepathy-glib/account-manager.h>
 #include <telepathy-glib/util.h>
@@ -43,7 +42,6 @@
 #include "empathy-accounts-common.h"
 #include "empathy-accounts-dialog.h"
 #include "empathy-account-assistant.h"
-#include "empathy-import-mc4-accounts.h"
 #include "empathy-auto-salut-account-helper.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
@@ -84,26 +82,15 @@ empathy_accounts_has_accounts (TpAccountManager *manager)
   return has_accounts;
 }
 
-void
-empathy_accounts_import (TpAccountManager *account_mgr,
-    EmpathyConnectionManagers *cm_mgr)
-{
-  g_return_if_fail (tp_account_manager_is_prepared (account_mgr,
-      TP_ACCOUNT_MANAGER_FEATURE_CORE));
-  g_return_if_fail (empathy_connection_managers_is_ready (cm_mgr));
-
-  if (!empathy_import_mc4_has_imported ())
-    empathy_import_mc4_accounts (cm_mgr);
-}
-
 static void
 do_show_accounts_ui (TpAccountManager *manager,
     TpAccount *account,
     GCallback window_destroyed_cb)
 {
-  GtkWidget *accounts_window;
+  static GtkWidget *accounts_window = NULL;
 
-  accounts_window = empathy_accounts_dialog_show (NULL, account);
+  if (accounts_window == NULL)
+    accounts_window = empathy_accounts_dialog_show (NULL, account);
 
   if (window_destroyed_cb)
     g_signal_connect (accounts_window, "destroy", window_destroyed_cb, NULL);
