@@ -45,6 +45,7 @@
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-tp-contact-factory.h>
 #include <libempathy/empathy-contact-list.h>
+#include <libempathy/empathy-request-util.h>
 
 #include <libempathy-gtk/empathy-images.h>
 #include <libempathy-gtk/empathy-contact-dialogs.h>
@@ -149,7 +150,8 @@ static const GtkTargetEntry drag_types_dest_file[] = {
 	{ "text/uri-list", 0, DND_DRAG_TYPE_URI_LIST },
 };
 
-static void chat_window_update (EmpathyChatWindow *window);
+static void chat_window_update (EmpathyChatWindow *window,
+		gboolean update_contact_menu);
 
 static void empathy_chat_window_add_chat (EmpathyChatWindow *window,
 			      EmpathyChat	*chat);
@@ -349,7 +351,7 @@ _submenu_notify_visible_changed_cb (GObject    *object,
 	g_signal_handlers_disconnect_by_func (object,
 					      _submenu_notify_visible_changed_cb,
 					      userdata);
-	chat_window_update (EMPATHY_CHAT_WINDOW (userdata));
+	chat_window_update (EMPATHY_CHAT_WINDOW (userdata), TRUE);
 }
 
 static void
@@ -417,12 +419,15 @@ chat_window_contact_menu_update (EmpathyChatWindowPriv *priv,
 
 	if (orig_submenu == NULL || !gtk_widget_get_visible (orig_submenu)) {
 		submenu = empathy_chat_get_contact_menu (priv->current_chat);
+
 		if (submenu != NULL) {
+			/* gtk_menu_attach_to_widget () doesn't behave nicely here */
+			g_object_set_data (G_OBJECT (submenu), "window", priv->dialog);
+
 			gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu), submenu);
 			gtk_widget_show (menu);
 			gtk_widget_set_sensitive (menu, TRUE);
-		}
-		else {
+		} else {
 			gtk_widget_set_sensitive (menu, FALSE);
 		}
 	} else {
@@ -577,7 +582,8 @@ chat_window_close_button_update (EmpathyChatWindowPriv *priv,
 }
 
 static void
-chat_window_update (EmpathyChatWindow *window)
+chat_window_update (EmpathyChatWindow *window,
+		    gboolean update_contact_menu)
 {
 	EmpathyChatWindowPriv *priv = GET_PRIV (window);
 	gint                   num_pages;
@@ -590,8 +596,14 @@ chat_window_update (EmpathyChatWindow *window)
 
 	chat_window_conversation_menu_update (priv, window);
 
-	chat_window_contact_menu_update (priv,
-					 window);
+	/* If this update is due to a focus-in event, we know the menu will be
+	   the same as when we last left it, so no work to do.  Besides, if we
+	   swap out the menu on a focus-in, we may confuse any external global
+	   menu watching. */
+	if (update_contact_menu) {
+		chat_window_contact_menu_update (priv,
+						 window);
+	}
 
 	chat_window_title_update (priv);
 
@@ -619,7 +631,8 @@ append_markup_printf (GString    *string,
 }
 
 static void
-chat_window_update_chat_tab (EmpathyChat *chat)
+chat_window_update_chat_tab_full (EmpathyChat *chat,
+				  gboolean update_contact_menu)
 {
 	EmpathyChatWindow     *window;
 	EmpathyChatWindowPriv *priv;
@@ -723,10 +736,16 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 
 	/* Update the window if it's the current chat */
 	if (priv->current_chat == chat) {
-		chat_window_update (window);
+		chat_window_update (window, update_contact_menu);
 	}
 }
 
+static void
+chat_window_update_chat_tab (EmpathyChat *chat)
+{
+	chat_window_update_chat_tab_full (chat, TRUE);
+}
+
 static void
 chat_window_chat_notify_cb (EmpathyChat *chat)
 {
@@ -1432,7 +1451,7 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 		chatroom = empathy_chatroom_manager_find (priv->chatroom_manager,
 							  account, room);
 
-		if (empathy_chatroom_is_always_urgent (chatroom)) {
+		if (chatroom != NULL && empathy_chatroom_is_always_urgent (chatroom)) {
 			needs_urgency = TRUE;
 		} else {
 			needs_urgency = empathy_message_should_highlight (message);
@@ -1615,7 +1634,7 @@ chat_window_page_removed_cb (GtkNotebook      *notebook,
 	if (priv->chats == NULL) {
 		g_object_unref (window);
 	} else {
-		chat_window_update (window);
+		chat_window_update (window, TRUE);
 	}
 }
 
@@ -1633,7 +1652,7 @@ chat_window_focus_in_event_cb (GtkWidget        *widget,
 	chat_window_set_urgency_hint (window, FALSE);
 
 	/* Update the title, since we now mark all unread messages as read. */
-	chat_window_update_chat_tab (priv->current_chat);
+	chat_window_update_chat_tab_full (priv->current_chat, FALSE);
 
 	return FALSE;
 }
@@ -1765,7 +1784,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 		}
 
 		if (!chat) {
-			empathy_dispatcher_chat_with_contact_id (
+			empathy_chat_with_contact_id (
 				account, contact_id, gtk_get_current_event_time ());
 
 			g_strfreev (strv);
