@@ -35,7 +35,7 @@
 
 #include <libempathy/empathy-contact.h>
 #include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-dispatcher.h>
+#include <libempathy/empathy-request-util.h>
 #include <libempathy/empathy-chatroom-manager.h>
 #include <libempathy/empathy-chatroom.h>
 #include <libempathy/empathy-contact-list.h>
@@ -50,6 +50,7 @@
 #include <libempathy-gtk/empathy-contact-list-store.h>
 #include <libempathy-gtk/empathy-contact-list-view.h>
 #include <libempathy-gtk/empathy-live-search.h>
+#include <libempathy-gtk/empathy-contact-blocking-dialog.h>
 #include <libempathy-gtk/empathy-contact-search-dialog.h>
 #include <libempathy-gtk/empathy-geometry.h>
 #include <libempathy-gtk/empathy-gtk-enum-types.h>
@@ -1156,7 +1157,7 @@ join_chatroom (EmpathyChatroom *chatroom,
 	room = empathy_chatroom_get_room (chatroom);
 
 	DEBUG ("Requesting channel for '%s'", room);
-	empathy_dispatcher_join_muc (account, room, timestamp);
+	empathy_join_muc (account, room, timestamp);
 }
 
 typedef struct
@@ -1463,6 +1464,18 @@ main_window_edit_personal_information_cb (GtkAction         *action,
 	empathy_contact_personal_dialog_show (GTK_WINDOW (window));
 }
 
+static void
+main_window_edit_blocked_contacts_cb (GtkAction         *action,
+		                      EmpathyMainWindow *window)
+{
+	GtkWidget *dialog;
+
+	dialog = empathy_contact_blocking_dialog_new (GTK_WINDOW (window));
+	gtk_widget_show (dialog);
+	g_signal_connect (dialog, "response",
+			G_CALLBACK (gtk_widget_destroy), NULL);
+}
+
 static void
 main_window_edit_preferences_cb (GtkAction         *action,
 				 EmpathyMainWindow *window)
@@ -1622,7 +1635,8 @@ main_window_connection_items_setup (EmpathyMainWindow *window,
 		"chat_new_message",
 		"chat_new_call",
 		"chat_add_contact",
-		"edit_personal_information"
+		"edit_personal_information",
+		"edit_blocked_contacts"
 	};
 
 	for (i = 0, list = NULL; i < G_N_ELEMENTS (actions_connected); i++) {
@@ -1801,6 +1815,7 @@ empathy_main_window_init (EmpathyMainWindow *window)
 			      "edit", "activate", main_window_edit_cb,
 			      "edit_accounts", "activate", main_window_edit_accounts_cb,
 			      "edit_personal_information", "activate", main_window_edit_personal_information_cb,
+			      "edit_blocked_contacts", "activate", main_window_edit_blocked_contacts_cb,
 			      "edit_preferences", "activate", main_window_edit_preferences_cb,
 			      "edit_search_contacts", "activate", main_window_edit_search_contacts_cb,
 			      "help_about", "activate", main_window_help_about_cb,
